@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 
 use Scalar::Util ();
 
@@ -12,7 +12,7 @@ use overload
     eq       =>  \&is_same_interface,
 ;
 
-my %DEFAULT = ( named => 0, optional => 0 );
+my %DEFAULT = ( named => 0, optional => 0, invocant => 0 );
 
 sub new {
     my $class = shift;
@@ -37,6 +37,7 @@ sub optional()   { !!$_[0]{optional} }
 sub required()   { !$_[0]{optional} }
 sub named()      { !!$_[0]{named} }
 sub positional() { !$_[0]{named} }
+sub invocant()   { !!$_[0]{invocant} }
 
 sub set_name($)      { $_[0]{name}     = $_[1];   $_[0] }
 sub set_type($)      { $_[0]{type}     = $_[1];   $_[0] }
@@ -46,6 +47,7 @@ sub set_optional($;)   { $_[0]{optional} = !!(defined $_[1] ? $_[1] : 1); $_[0]
 sub set_required($;)   { $_[0]{optional} =  !(defined $_[1] ? $_[1] : 1); $_[0] }
 sub set_named($;)      { $_[0]{named}    = !!(defined $_[1] ? $_[1] : 1); $_[0] }
 sub set_positional($;) { $_[0]{named}    =  !(defined $_[1] ? $_[1] : 1); $_[0] }
+sub set_invocant($;)   { $_[0]{invocant} = !!(defined $_[1] ? $_[1] : 1); $_[0] }
 
 # alias
 sub isa_() :method; # NOT isa
@@ -215,6 +217,14 @@ This boolean is the opposite of C<positional>.
 
 Setter for C<positional>.
 
+=head3 invocant
+
+A boolean value indicating whether to be invocant. Default to false.
+
+=head3 set_invocant($bool=true)
+
+Setter for C<invocant>.
+
 =head2 OTHERS
 
 =head3 is_same_interface($other_meta)
